@@ -28,7 +28,7 @@ Afrikaan_LO_Latest_full
    <fa>Afrikaans Language Meta-Package for LibreOffice</fa>
    <fil_PH>Afrikaans Language Meta-Package for LibreOffice</fil_PH>
    <fi>Afrikaaninen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Afrikaans Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet de langue afrikanns pour LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue afrikanns pour LibreOffice</fr>
    <gl_ES>Africánder meta-paquete de idioma para LiberOffice</gl_ES>
    <he_IL>חבילת על לשפת אפריקאנס עבור LibreOffice</he_IL>
