@@ -28,7 +28,7 @@ Amharic_LO_Latest_full
    <fa>Amharic Language Meta-Package for LibreOffice</fa>
    <fil_PH>Amharic Language Meta-Package for LibreOffice</fil_PH>
    <fi>Amharalainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Amharic Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet de langue amharique pour LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue amharique pour LibreOffice</fr>
    <gl_ES>Amárico Meta-paquete de idioma para LibreOffice</gl_ES>
    <he_IL>חבילת על לאמהרית עבור LibreOffice</he_IL>
