@@ -28,7 +28,7 @@ Chinese_CN_LO_main
    <fa>Chinese_simplified localisation of LibreOffice</fa>
    <fil_PH>Chinese_simplified localisation of LibreOffice</fil_PH>
    <fi>Yksinkertaistetun kiinankielen kotoistus LibreOffice:lle</fi>
-   <fr_BE>Chinese_simplified localisation of LibreOffice</fr_BE>
+   <fr_BE>Localisation en chinois-simplifié pour LibreOffice</fr_BE>
    <fr>Localisation en chinois-simplifié pour LibreOffice</fr>
    <gl_ES>Localización de LibreOffice en chinés simplificado</gl_ES>
    <he_IL>Chinese_simplified localisation of LibreOffice</he_IL>
