@@ -5,28 +5,32 @@
 Language
 </category>
 
-<name>  
+<name>
 Dutch_LO_Latest_full
 </name>
 
-<description>  
+<description>
    <am>Dutch LibreOffice Language Meta-Package</am>
    <ar>Dutch LibreOffice Language Meta-Package</ar>
+   <be>Dutch LibreOffice Language Meta-Package</be>
    <bg>Dutch LibreOffice Language Meta-Package</bg>
    <bn>Dutch LibreOffice Language Meta-Package</bn>
    <ca>Meta-paquet per LibreOffice en Holandès</ca>
    <cs>Dutch LibreOffice Language Meta-Package</cs>
    <da>Hollandsk LibreOffice sprog-metapakke</da>
    <de>Niederländisches LibreOffice Meta-Paket</de>
-   <el>Libreoffice για ολλανδική γλώσσα</el>
+   <el>Libreoffice στα Ολλανδικά</el>
    <en>Dutch LibreOffice Language Meta-Package</en>
-   <es>Meta-Paquete de Idioma Holandés LibreOffice</es>
+   <es_ES>Meta-Paquete de Idioma Holandés de LibreOffice</es_ES>
+   <es>Metapaquete de Idioma Holandés LibreOffice</es>
    <et>Dutch LibreOffice Language Meta-Package</et>
    <eu>Dutch LibreOffice Language Meta-Package</eu>
    <fa>Dutch LibreOffice Language Meta-Package</fa>
    <fil_PH>Dutch LibreOffice Language Meta-Package</fil_PH>
-   <fi>Dutch LibreOffice Language Meta-Package</fi>
+   <fi>Hollanninkielinen metatieto-paketti LibreOffice:lle</fi>
+   <fr_BE>Méta-Paquet langue néerlandaise pour LibreOffice</fr_BE>
    <fr>Méta-Paquet langue néerlandaise pour LibreOffice</fr>
+   <gl_ES>Neerlandés Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>Dutch LibreOffice Language Meta-Package</he_IL>
    <hi>Dutch LibreOffice Language Meta-Package</hi>
    <hr>Dutch LibreOffice Language Meta-Package</hr>
@@ -34,17 +38,18 @@ Dutch_LO_Latest_full
    <id>Dutch LibreOffice Language Meta-Package</id>
    <is>Dutch LibreOffice Language Meta-Package</is>
    <it>Meta-pacchetto della lingua olandese per LibreOffice</it>
-   <ja_JP>Dutch LibreOffice Language Meta-Package</ja_JP>
-   <ja>Dutch LibreOffice Language Meta-Package</ja>
+   <ja>オランダ語の LibreOffice言語メタパッケージ</ja>
    <kk>Dutch LibreOffice Language Meta-Package</kk>
    <ko>Dutch LibreOffice Language Meta-Package</ko>
    <lt>Dutch LibreOffice Language Meta-Package</lt>
    <mk>Dutch LibreOffice Language Meta-Package</mk>
    <mr>Dutch LibreOffice Language Meta-Package</mr>
-   <nb>Dutch LibreOffice Language Meta-Package</nb>
+   <nb_NO>Dutch LibreOffice Language Meta-Package</nb_NO>
+   <nb>Nederlandsk språkpakke for LibreOffice</nb>
+   <nl_BE>Dutch LibreOffice Language Meta-Package</nl_BE>
    <nl>Nederlandse LibreOffice Taal Meta-Pakket</nl>
    <pl>Holenderski metapakiet językowy dla LibreOffice</pl>
-   <pt_BR>Holandês Meta-Pacote de Idioma para LibreOffice</pt_BR>
+   <pt_BR>Holandês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Holandês Meta-Pacote de Idioma para LibreOffice</pt>
    <ro>Dutch LibreOffice Language Meta-Package</ro>
    <ru>Dutch LibreOffice Language Meta-Package</ru>
@@ -53,10 +58,12 @@ Dutch_LO_Latest_full
    <sq>Dutch LibreOffice Language Meta-Package</sq>
    <sr>Dutch LibreOffice Language Meta-Package</sr>
    <sv>Holländska LibreOffice Språk Meta-Paket</sv>
-   <tr>Dutch LibreOffice Language Meta-Package</tr>
+   <th>Meta-Package ภาษา Dutch สำหรับ LibreOffice</th>
+   <tr>Flemenkçe LibreOffice Dil Üst-Paketi</tr>
    <uk>Dutch LibreOffice Language Meta-Package</uk>
    <vi>Dutch LibreOffice Language Meta-Package</vi>
-   <zh_CN>Dutch LibreOffice Language Meta-Package</zh_CN>
+   <zh_CN>LibreOffice 荷兰语语言包</zh_CN>
+   <zh_HK>Dutch LibreOffice Language Meta-Package</zh_HK>
    <zh_TW>Dutch LibreOffice Language Meta-Package</zh_TW>
 </description>
 
