@@ -5,28 +5,32 @@
 Language
 </category>
 
-<name>  
+<name>
 French_LO_Latest_full
 </name>
 
-<description>  
+<description>
    <am>French Language Meta-Package for LibreOffice</am>
    <ar>French Language Meta-Package for LibreOffice</ar>
+   <be>French Language Meta-Package for LibreOffice</be>
    <bg>French Language Meta-Package for LibreOffice</bg>
    <bn>French Language Meta-Package for LibreOffice</bn>
    <ca>Meta paquet per LibreOffice en llengua francesa</ca>
    <cs>French Language Meta-Package for LibreOffice</cs>
    <da>Fransk sprog-metapakke til LibreOffice</da>
    <de>Französisches Meta-Paket für LibreOffice</de>
-   <el>LibreOffice στη γαλλική γλώσσα</el>
+   <el>LibreOffice στα Γαλλικά</el>
    <en>French Language Meta-Package for LibreOffice</en>
-   <es>Meta-Paquete de Idioma Francés para LibreOffice</es>
+   <es_ES>Meta-Paquete de Idioma Francés para LibreOffice</es_ES>
+   <es>Metapaquete de Idioma Francés para LibreOffice</es>
    <et>French Language Meta-Package for LibreOffice</et>
    <eu>French Language Meta-Package for LibreOffice</eu>
    <fa>French Language Meta-Package for LibreOffice</fa>
    <fil_PH>French Language Meta-Package for LibreOffice</fil_PH>
-   <fi>French Language Meta-Package for LibreOffice</fi>
+   <fi>Ranskalainen kielipaketti LibreOffice:lle</fi>
+   <fr_BE>Méta-paquet langue française pour LibreOffice</fr_BE>
    <fr>Méta-paquet langue française pour LibreOffice</fr>
+   <gl_ES>Francés Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>French Language Meta-Package for LibreOffice</he_IL>
    <hi>French Language Meta-Package for LibreOffice</hi>
    <hr>French Language Meta-Package for LibreOffice</hr>
@@ -34,17 +38,18 @@ French_LO_Latest_full
    <id>French Language Meta-Package for LibreOffice</id>
    <is>French Language Meta-Package for LibreOffice</is>
    <it>Meta-pacchetto della lingua francese per LibreOffice</it>
-   <ja_JP>French Language Meta-Package for LibreOffice</ja_JP>
-   <ja>French Language Meta-Package for LibreOffice</ja>
+   <ja>LibreOffice用のフランス語メタパッケージ</ja>
    <kk>French Language Meta-Package for LibreOffice</kk>
    <ko>French Language Meta-Package for LibreOffice</ko>
    <lt>French Language Meta-Package for LibreOffice</lt>
    <mk>French Language Meta-Package for LibreOffice</mk>
    <mr>French Language Meta-Package for LibreOffice</mr>
-   <nb>French Language Meta-Package for LibreOffice</nb>
+   <nb_NO>French Language Meta-Package for LibreOffice</nb_NO>
+   <nb>Fransk språkpakke for LibreOffice</nb>
+   <nl_BE>French Language Meta-Package for LibreOffice</nl_BE>
    <nl>Franse Taal Meta-Pakket voor LibreOffice</nl>
    <pl>Francuski metapakiet językowy dla LibreOffice</pl>
-   <pt_BR>Francês Meta-Pacote de Idioma para LibreOffice</pt_BR>
+   <pt_BR>Francês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Francês Meta-Pacote de Idioma para LibreOffice</pt>
    <ro>French Language Meta-Package for LibreOffice</ro>
    <ru>French Language Meta-Package for LibreOffice</ru>
@@ -53,10 +58,12 @@ French_LO_Latest_full
    <sq>French Language Meta-Package for LibreOffice</sq>
    <sr>French Language Meta-Package for LibreOffice</sr>
    <sv>Franskt Språk Meta-Paket för LibreOffice</sv>
-   <tr>French Language Meta-Package for LibreOffice</tr>
+   <th>Meta-Package ภาษา French สำหรับ LibreOffice</th>
+   <tr>LibreOffice için Fransızca Dili Üst-Paketi</tr>
    <uk>French Language Meta-Package for LibreOffice</uk>
    <vi>French Language Meta-Package for LibreOffice</vi>
-   <zh_CN>French Language Meta-Package for LibreOffice</zh_CN>
+   <zh_CN>LibreOffice 法语语言包</zh_CN>
+   <zh_HK>French Language Meta-Package for LibreOffice</zh_HK>
    <zh_TW>French Language Meta-Package for LibreOffice</zh_TW>
 </description>
 
