@@ -28,7 +28,7 @@ Italian_LO_Latest_full
    <fa>Italian LibreOffice Language Meta-Package</fa>
    <fil_PH>Italian LibreOffice Language Meta-Package</fil_PH>
    <fi>Italialainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Italian LibreOffice Language Meta-Package</fr_BE>
+   <fr_BE>Méta-paquet langue italienne pour LibreOffice</fr_BE>
    <fr>Méta-paquet langue italienne pour LibreOffice</fr>
    <gl_ES>Italiano Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>Italian LibreOffice Language Meta-Package</he_IL>
