@@ -28,7 +28,7 @@ Venda_LO_full
    <fa>Venda Language Meta-Package for LibreOffice</fa>
    <fil_PH>Venda Language Meta-Package for LibreOffice</fil_PH>
    <fi>Vendankielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Venda Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet de langues Venda pour LibreOffice</fr_BE>
    <fr>Méta-Paquet de langues Venda pour LibreOffice</fr>
    <gl_ES>Venda Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>Venda Language Meta-Package for LibreOffice</he_IL>
