@@ -28,7 +28,7 @@ LXDE
    <fa>basic install of LXDE</fa>
    <fil_PH>basic install of LXDE</fil_PH>
    <fi>LXDE-työpöydän perusasennus</fi>
-   <fr_BE>basic install of LXDE</fr_BE>
+   <fr_BE>Installation de base du bureau LXDE</fr_BE>
    <fr>Installation de base du bureau LXDE</fr>
    <gl_ES>Instalación básica do Ambiente de Traballo LXDE</gl_ES>
    <he_IL>התקנה בסיסית של LXDE</he_IL>
