@@ -28,7 +28,7 @@ QT5 Documention
    <fa>Documentation files for Qt-5 and QtCreator IDE</fa>
    <fil_PH>Documentation files for Qt-5 and QtCreator IDE</fil_PH>
    <fi>Dokumentaatiotiedostot Qt-5 ja QtCreator ohjelmakehitysympäristölle</fi>
-   <fr_BE>Documentation files for Qt-5 and QtCreator IDE</fr_BE>
+   <fr_BE>Fichiers de documentation pour Qt-5 et QtCreator IDE</fr_BE>
    <fr>Fichiers de documentation pour Qt-5 et QtCreator IDE</fr>
    <gl_ES>Documentation files for Qt-5 and QtCreator IDE</gl_ES>
    <he_IL>Documentation files for Qt-5 and QtCreator IDE</he_IL>
